module Debate.Arguments.Nutrition.HealthyFood exposing (..)

import Debate.Types exposing (..)


argumentHealthyFood : Argument
argumentHealthyFood =
    { argumentTitle = "Argument For Healthy Food Substitution"
    , propositionTitle = "Pepsi is healthy compared to leafy greens when trapped on a desert island."
    , propositionSummary = "Summary"
    , proofLink  = "https://www.umsu.de/trees/#(~6x~6y~6z~6w(Pxyw~4Qxyzw)),(Qpdsl)%7C=(Ppdl)"
    , definitionTable =
        [ { definiendum = "P(x,y,w)"
          , definiens = "a given (x) is healthy compared to a given (w) when in a given (y)"
          }
        , { definiendum = "Q(x,y,z,w)"
          , definiens = "when within a (y) the consumption of the given (x) is likely to increase the lag-time to the onset of (z) when replacing a given (w)"
          }
        , { definiendum = "p"
          , definiens = "Pepsi"
          }
        , { definiendum = "d"
          , definiens = "trapped on a desert island"
          }
        , { definiendum = "s"
          , definiens = "starvation"
          }
        , { definiendum = "l"
          , definiens = "leafy greens"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "A given food is healthy compared to another given food when in a given context if, and only if, when within that context the consumption of that given food is likely to increase the lag-time to the onset of illness, disease, or infirmity when replacing a given other food."
                  , notation = "(∀x∀y∀z∀w(Pxyw↔Qxyzw))"
                  }
                , { premise = "When trapped on a desert island the consumption of Pepsi increases the lag-time to the onset of starvation when replacing leafy greens."
                  , notation = "(Qpdsl)"
                  }
                ]
          , conclusion = "Therefore, Pepsi is healthy compared to leafy greens when trapped on a desert island."
          , conclusionNotation = "(∴Ppdl)"
          }
        ]
    }